@@ -191,7 +191,7 @@ class QualityAssessments:
         
         error_message, error_occured = '', False
         new_dict = {}
-        new_dict['datetime'] = pd.to_datetime(datetime.now())
+        new_dict['datetime'] = str(datetime.now())
         for col in cols_to_check:
             new_dict[col] = df[col].sum()
 
@@ -201,7 +201,7 @@ class QualityAssessments:
         if os.path.isdir('Historic df Comparison (Do Not Delete)') == False:
             os.mkdir('Historic df Comparison (Do Not Delete)')
         if os.path.exists(f'Historic df Comparison (Do Not Delete)/{name_of_df}_previous_totals.json') ==False:
-            self.util.pickle_data(new_dict,f'{name_of_df}_previous_totals',folder='Historic df Comparison (Do Not Delete)/')
+            self.util.write_json(new_dict,f'{name_of_df}_previous_totals',file_type='append',folder='Historic df Comparison (Do Not Delete)/')
             logger.info(f"Creation of {name_of_df}_previous_totals")
             logger.info(new_dict)
             return
@@ -382,3 +382,5 @@ class QualityAssessments:
                     output_df[f'{label} ("{tag}")'] = output_df[level[1]].apply(lambda x: return_value(x,tag,acceptable_values))
             self.util.write_to_gsheet(workbook_name = gsheet_name,sheet_name= level[2],df = output_df)
     
+
+# %%
